@@ -9,28 +9,28 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("2.6.") or
-    raise "ruby lib version (2.6.10) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("2.7.") or
+    raise "ruby lib version (2.7.8) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby2.6/2.6.0/i386-darwin10.0")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby2.7/2.7.0/i386-darwin10.0")
   # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
-  CONFIG["MINOR"] = "6"
-  CONFIG["TEENY"] = "10"
-  CONFIG["PATCHLEVEL"] = "210"
+  CONFIG["MINOR"] = "7"
+  CONFIG["TEENY"] = "8"
+  CONFIG["PATCHLEVEL"] = "225"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/opt/local")
-  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)2.6"
-  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)2.6"
+  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)2.7"
+  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)2.7"
   CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME).$(RUBY_API_VERSION)"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-2.6.pc"
+  CONFIG["ruby_pc"] = "ruby-2.7.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
@@ -44,7 +44,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-gmp' '--with-opt-dir=/opt/local' '--program-suffix=2.6' '--with-rubylibprefix=/opt/local/lib/ruby2.6' '--with-openssl-include=/opt/local/libexec/openssl11/include' '--with-openssl-lib=/opt/local/libexec/openssl11/lib' '--with-arch=i386' '--disable-dtrace' 'CC=/opt/local/bin/clang-mp-11' 'CFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -std=c99 -arch i386' 'LDFLAGS=-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch i386' 'CPPFLAGS=-I/opt/local/libexec/openssl11/include -isystem/opt/local/include' 'CXX=/opt/local/bin/clang++-mp-11' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++ -arch i386'"
+  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-gmp' '--with-opt-dir=/opt/local' '--program-suffix=2.7' '--with-rubylibprefix=/opt/local/lib/ruby2.7' '--with-openssl-dir=/opt/local/libexec/openssl11' '--without-baseruby' '--with-arch=i386' '--disable-dtrace' 'CC=/opt/local/bin/clang-mp-11' 'CFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -std=c99 -arch i386' 'LDFLAGS=-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch i386' 'CPPFLAGS=-I/opt/local/libexec/openssl11/include -isystem/opt/local/include' 'CXX=/opt/local/bin/clang++-mp-11' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++ -arch i386'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -54,7 +54,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "2.6.0"
+  CONFIG["ruby_version"] = "2.7.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "i386-darwin10.0"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -92,10 +92,10 @@ module RbConfig
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
-  CONFIG["EXTDLDFLAGS"] = ""
+  CONFIG["EXTDLDFLAGS"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = ""
-  CONFIG["warnflags"] = "-Wall -Wextra -Wdeclaration-after-statement -Wdeprecated-declarations -Wdivision-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wmisleading-indentation -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wmissing-noreturn -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wextra-tokens"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wdivision-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wmisleading-indentation -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wmissing-noreturn -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wextra-tokens"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3"
   CONFIG["NULLCMD"] = ":"
@@ -110,7 +110,7 @@ module RbConfig
   CONFIG["PREP"] = "miniruby$(EXEEXT)"
   CONFIG["CROSS_COMPILING"] = "no"
   CONFIG["TEST_RUNNABLE"] = "yes"
-  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby2.6"
+  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby2.7"
   CONFIG["setup"] = "Setup"
   CONFIG["ENCSTATIC"] = ""
   CONFIG["EXTSTATIC"] = ""
@@ -122,6 +122,7 @@ module RbConfig
   CONFIG["RPATHFLAG"] = ""
   CONFIG["LIBPATHFLAG"] = " -L%s"
   CONFIG["LINK_SO"] = "\n$(POSTLINK)"
+  CONFIG["ADDITIONAL_DLDFLAGS"] = ""
   CONFIG["ASMEXT"] = "S"
   CONFIG["LIBEXT"] = "a"
   CONFIG["DLEXT2"] = ""
@@ -131,7 +132,7 @@ module RbConfig
   CONFIG["CCDLFLAGS"] = "-fno-common"
   CONFIG["STATIC"] = ""
   CONFIG["ARCH_FLAG"] = " -arch i386"
-  CONFIG["DLDFLAGS"] = "-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch i386 -Wl,-undefined,dynamic_lookup -Wl,-multiply_defined,suppress -L/opt/local/lib"
+  CONFIG["DLDFLAGS"] = "-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch i386 -Wl,-multiply_defined,suppress -Wl,-undefined,dynamic_lookup -L/opt/local/lib"
   CONFIG["ALLOCA"] = ""
   CONFIG["MATHN"] = "yes"
   CONFIG["dsymutil"] = "dsymutil"
@@ -177,9 +178,9 @@ module RbConfig
   CONFIG["GCC"] = "yes"
   CONFIG["EGREP"] = "/usr/bin/grep -E"
   CONFIG["GREP"] = "/usr/bin/grep"
-  CONFIG["CPP"] = "$(CC) -E"
   CONFIG["CXXFLAGS"] = "-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++"
   CONFIG["CXX"] = "/opt/local/bin/clang++-mp-11"
+  CONFIG["CPP"] = "$(CC) -E"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-I/opt/local/libexec/openssl11/include -isystem/opt/local/include -I/opt/local/include -D_XOPEN_SOURCE -D_DARWIN_C_SOURCE -D_DARWIN_UNLIMITED_SELECT -D_REENTRANT $(DEFS) $(cppflags)"
   CONFIG["LDFLAGS"] = "-L. -L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -fstack-protector-strong -L/opt/local/libexec/llvm-11/lib/clang/11.1.0/lib -L/opt/local/lib"
@@ -189,10 +190,10 @@ module RbConfig
   CONFIG["target_vendor"] = "apple"
   CONFIG["target_cpu"] = "i386"
   CONFIG["target"] = "i386-apple-darwin10.0"
-  CONFIG["host_os"] = "darwin10.8.0"
+  CONFIG["host_os"] = "darwin10.0"
   CONFIG["host_vendor"] = "apple"
   CONFIG["host_cpu"] = "i386"
-  CONFIG["host"] = "i386-apple-darwin10.8.0"
+  CONFIG["host"] = "i386-apple-darwin10.0"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
@@ -200,11 +201,11 @@ module RbConfig
   CONFIG["build_vendor"] = "apple"
   CONFIG["build_cpu"] = "i386"
   CONFIG["build"] = "i386-apple-darwin10.8.0"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "$(MAJOR).$(MINOR).$(TEENY)"
   CONFIG["RUBY_API_VERSION"] = "$(MAJOR).$(MINOR)"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.6.10"
   CONFIG["HAVE_GIT"] = "no"
   CONFIG["GIT"] = "git"
-  CONFIG["cxxflags"] = "$(optflags) $(debugflags) $(warnflags)"
+  CONFIG["cxxflags"] = ""
   CONFIG["cppflags"] = ""
   CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
   CONFIG["target_alias"] = ""
@@ -235,7 +236,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
-  CONFIG["program_transform_name"] = "s&$$&2.6&;s&^&&"
+  CONFIG["program_transform_name"] = "s&$$&2.7&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
@@ -246,7 +247,7 @@ module RbConfig
   CONFIG["PATH_SEPARATOR"] = ":"
   CONFIG["SHELL"] = "/bin/sh"
   CONFIG["UNICODE_VERSION"] = "12.1.0"
-  CONFIG["UNICODE_EMOJI_VERSION"] = "12.0"
+  CONFIG["UNICODE_EMOJI_VERSION"] = "12.1"
   CONFIG["SDKROOT"] = "#{ENV['SDKROOT']}" # don't run xcrun every time, usually useless.
   CONFIG["archdir"] = "$(rubyarchdir)"
   CONFIG["topdir"] = File.dirname(__FILE__)
@@ -324,7 +325,7 @@ module RbConfig
   #
   # returns updated keys list, or +nil+ if nothing changed.
   def RbConfig.fire_update!(key, val, mkconf = MAKEFILE_CONFIG, conf = CONFIG)
-    return if (old = mkconf[key]) == val
+    return if mkconf[key] == val
     mkconf[key] = val
     keys = [key]
     deps = []
